pub struct SyncOrchestrator {
pub database: Arc<SyncDatabase>,
pub motion_client: Arc<MotionClient>,
}Fields
database: Arc<SyncDatabase>motion_client: Arc<MotionClient>Implementations
Sourceimpl SyncOrchestrator
impl SyncOrchestrator
pub async fn new(config: &AppConfig) -> Result<Self>
pub async fn run_full_sync( &self, config: &AppConfig, force_update: bool, ) -> Result<()>
Sourcepub async fn sync_completed_tasks(&self, config: &AppConfig) -> Result<()>
pub async fn sync_completed_tasks(&self, config: &AppConfig) -> Result<()>
Check for completed tasks in Motion and tag corresponding Linear issues
Sourcepub async fn cleanup_unassigned_tasks(&self, config: &AppConfig) -> Result<()>
pub async fn cleanup_unassigned_tasks(&self, config: &AppConfig) -> Result<()>
Clean up Motion tasks for Linear issues that are no longer assigned to the user